@@ -33,7 +33,7 @@
 
 #ifndef lint
 /*static char sccsid[] = "from: @(#)recvjob.c	5.15 (Berkeley) 5/4/91";*/
-static char rcsid[] = "$Id: recvjob.c,v 1.6 1999/10/23 05:50:39 notting Exp $";
+static char rcsid[] = "$Id: recvjob.c,v 1.2 1993/08/01 17:58:49 mycroft Exp $";
 #endif /* not lint */
 
 /*
@@ -45,22 +45,15 @@ static char rcsid[] = "$Id: recvjob.c,v 1.6 1999/10/23 05:50:39 notting Exp $";
 #include "pathnames.h"
 #include <sys/mount.h>
 
-#include <stdlib.h>
-
 char	*sp = "";
 #define ack()	(void) write(1, sp, 1);
 
-char    tfname[FILENAMELEN];	/* tmp copy of cf before linking */
-char    dfname[FILENAMELEN];	/* data files */
+char    tfname[40];		/* tmp copy of cf before linking */
+char    dfname[40];		/* data files */
 int	minfree;		/* keep at least minfree blocks available */
 
 void	rcleanup();
 
-struct qfile {
-	char fname[FILENAMELEN];
-	uid_t uid;
-};
-
 recvjob()
 {
 	struct stat stb;
@@ -113,13 +106,7 @@ readjob()
 {
 	register int size, nfiles;
 	register char *cp;
-	int num=0, x;
-	struct qfile *qfiles=NULL;
-	struct passwd *user;
-	struct group *lpgrp;
-	FILE *cfile;
 
-	lpgrp = getgrnam("lp");
 	ack();
 	nfiles = 0;
 	for (;;) {
@@ -131,14 +118,9 @@ readjob()
 			if ((size = read(1, cp, 1)) != 1) {
 				if (size < 0)
 					frecverr("%s: Lost connection",printer);
-				if (qfiles)
-				  for (x=0;x<=num;x++) {
-					chown(qfiles[x].fname,qfiles[x].uid,
-					       lpgrp->gr_gid);
-				  }
 				return(nfiles);
 			}
-		} while (*cp++ != '\n' && (cp - line + 1) < sizeof(line));
+		} while (*cp++ != '\n');
 		*--cp = '\0';
 		cp = line;
 		switch (*cp++) {
@@ -147,7 +129,6 @@ readjob()
 			continue;
 
 		case '\2':	/* read cf file */
-			user = getpwnam("lp");
 			size = 0;
 			while (*cp >= '0' && *cp <= '9')
 				size = size * 10 + (*cp++ - '0');
@@ -159,13 +140,9 @@ readjob()
 			 * something different than what gethostbyaddr()
 			 * returns
 			 */
-			strncpy(cp + 6, from, sizeof(line) + line - cp - 7);
-			line[sizeof(line) - 1] = '\0';
-			strncpy(tfname, cp, sizeof(tfname) - 1);
-			tfname[sizeof(tfname)-1] = '\0';
+			strcpy(cp + 6, from);
+			strcpy(tfname, cp);
 			tfname[0] = 't';
-			if (strchr(tfname, '/'))
-				frecverr("readjob: %s: illegal path name", tfname);
 			if (!chksize(size)) {
 				(void) write(1, "\2", 1);
 				continue;
@@ -179,25 +156,6 @@ readjob()
 			(void) unlink(tfname);
 			tfname[0] = '\0';
 			nfiles++;
-			cfile=fopen(cp,"r");
-			if (cfile!=NULL) {
-				while (getline(cfile)) {
-					if (line[0]=='P') {
-						user=getpwnam(line+1);
-						if (user==NULL)
-						  user=getpwnam("lp");
-					} else if (line[0]>='a' && line[0]<='z') {
-						qfiles = realloc(qfiles,(num+1)*
-							       sizeof(struct qfile));
-						strncpy(qfiles[num].fname, line+1,
-							sizeof(qfiles[num].fname));
-						qfiles[num].fname[sizeof(qfiles[num].fname)-1]='\0';
-						qfiles[num].uid = user->pw_uid;
-						num++;
-					}
-				}
-				fclose(cfile);
-			}
 			continue;
 
 		case '\3':	/* read df file */
@@ -210,8 +168,7 @@ readjob()
 				(void) write(1, "\2", 1);
 				continue;
 			}
-			(void) strncpy(dfname, cp, sizeof(dfname)-1);
-			dfname[sizeof(dfname)-1] = '\0';
+			(void) strcpy(dfname, cp);
 			if (index(dfname, '/'))
 				frecverr("readjob: %s: illegal path name",
 					dfname);
@@ -235,7 +192,6 @@ readfile(file, size)
 	int fd, err;
 
 	fd = open(file, O_CREAT|O_EXCL|O_WRONLY, FILMOD);
-
 	if (fd < 0)
 		frecverr("readfile: %s: illegal path name: %m", file);
 	ack();
@@ -264,7 +220,6 @@ readfile(file, size)
 	if (err)
 		frecverr("%s: write error", file);
 	if (noresponse()) {		/* file sent had bad data in it */
-		if (strchr(file, '/') == NULL)
 		(void) unlink(file);
 		return(0);
 	}
@@ -331,16 +286,15 @@ void
 rcleanup()
 {
 
-	if (tfname[0] && strchr(tfname, '/') == NULL)
+	if (tfname[0])
 		(void) unlink(tfname);
-	if (dfname[0] && strchr(dfname, '/') == NULL) {
+	if (dfname[0])
 		do {
 			do
 				(void) unlink(dfname);
 			while (dfname[2]-- != 'A');
 			dfname[2] = 'z';
 		} while (dfname[0]-- != 'd');
-	}
 	dfname[0] = '\0';
 }
 
